## 0.4.11 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.4.9 (2021-12-16)

mypy_extensions: fix NoReturn, remove inaccurate comment (#6595)

## 0.4.8 (2021-10-12)

Add star to all non-0.1 versions (#6146)

